@@ -1,8 +1,7 @@
 #
 # __init__.py
 #
-# Copyright (C) 2017 frnmst (Franco Masotti) <franco.masotti@live.com>
-#                                            <franco.masotti@student.unife.it>
+# Copyright (C) 2017-2020 frnmst (Franco Masotti) <franco.masotti@live.com>
 #
 # This file is part of fpyutils.
 #
@@ -23,4 +22,4 @@
 
 from .filelines import (insert_string_at_line, remove_line_interval,
                         get_line_matches)
-from .exceptions import (LineOutOfFileBoundsError)
+from .exceptions import (LineOutOfFileBoundsError, NegativeLineRangeError)
